@@ -25,6 +25,16 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/memcache_pool_flush_on_reconnect').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/memcache_sasl_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/memcache_username').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/memcache_password').with_value('<SERVICE DEFAULT>').with_secret(true)
+        is_expected.to contain_keystone_config('cache/redis_server').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/redis_username').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/redis_password').with_value('<SERVICE DEFAULT>').with_secret(true)
+        is_expected.to contain_keystone_config('cache/redis_sentinels').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/redis_socket_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/redis_sentinel_service_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/tls_enabled').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/tls_cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/tls_certfile').with_value('<SERVICE DEFAULT>')
@@ -59,6 +69,16 @@ describe 'oslo::cache' do
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '60',
           :memcache_pool_connection_get_timeout => '10',
+          :memcache_pool_flush_on_reconnect     => false,
+          :memcache_sasl_enabled                => false,
+          :memcache_username                    => 'sasluser',
+          :memcache_password                    => 'saslpass',
+          :redis_server                         => 'localhost:6379',
+          :redis_username                       => 'redisuser',
+          :redis_password                       => 'redispass',
+          :redis_sentinels                      => ['host1:26379', 'host2:26379'],
+          :redis_socket_timeout                 => 1.0,
+          :redis_sentinel_service_name          => 'mymaster',
           :tls_enabled                          => false,
           :tls_cafile                           => '/path/to/ssl/cafile',
           :tls_certfile                         => '/path/to/ssl/certfile',
@@ -91,6 +111,16 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('10')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('10')
+        is_expected.to contain_keystone_config('cache/memcache_pool_flush_on_reconnect').with_value(false)
+        is_expected.to contain_keystone_config('cache/memcache_sasl_enabled').with_value(false)
+        is_expected.to contain_keystone_config('cache/memcache_username').with_value('sasluser')
+        is_expected.to contain_keystone_config('cache/memcache_password').with_value('saslpass').with_secret(true)
+        is_expected.to contain_keystone_config('cache/redis_server').with_value('localhost:6379')
+        is_expected.to contain_keystone_config('cache/redis_username').with_value('redisuser')
+        is_expected.to contain_keystone_config('cache/redis_password').with_value('redispass').with_secret(true)
+        is_expected.to contain_keystone_config('cache/redis_sentinels').with_value('host1:26379,host2:26379')
+        is_expected.to contain_keystone_config('cache/redis_socket_timeout').with_value(1.0)
+        is_expected.to contain_keystone_config('cache/redis_sentinel_service_name').with_value('mymaster')
         is_expected.to contain_keystone_config('cache/tls_enabled').with_value('false')
         is_expected.to contain_keystone_config('cache/tls_cafile').with_value('/path/to/ssl/cafile')
         is_expected.to contain_keystone_config('cache/tls_certfile').with_value('/path/to/ssl/certfile')
@@ -150,16 +180,16 @@ describe 'oslo::cache' do
       end
     end
 
-    context 'with memcache backend' do
+    context 'with memcached backend' do
       let :params do
         {
-          :backend          => 'dogpile.cache.memcache',
+          :backend          => 'dogpile.cache.memcached',
           :memcache_servers => ['host1:11211', 'host2:11211','[fd12:3456:789a:1::1]:11211'],
         }
       end
 
       it 'configures cache backend' do
-        is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcache')
+        is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached')
         is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,inet6:[fd12:3456:789a:1::1]:11211')
         is_expected.to contain_package('python-memcache').with(
           :ensure => 'installed',
@@ -197,6 +227,53 @@ describe 'oslo::cache' do
       end
     end
 
+    context 'with bymemcache backend' do
+      let :params do
+        {
+          :backend          => 'dogpile.cache.bmemcached',
+          :memcache_servers => ['host1:11211', 'host2:11211','[fd12:3456:789a:1::1]:11211'],
+        }
+      end
+
+      it 'configures cache backend' do
+        is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.bmemcached')
+        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,[fd12:3456:789a:1::1]:11211')
+        is_expected.to contain_package('python-binary-memcached').with(
+          :ensure => 'installed',
+          :name   => platform_params[:python_bmemcached_package_name],
+          :tag    => ['openstack'],
+        )
+      end
+
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-binary-memcached').with(
+            :ensure => 'latest',
+            :name   => platform_params[:python_bmemcached_package_name],
+            :tag    => ['openstack'],
+          )
+        end
+      end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.to_not contain_package('python-binary-memcached')
+        end
+      end
+    end
+
     context 'with pymemcache backend' do
       let :params do
         {
@@ -244,6 +321,96 @@ describe 'oslo::cache' do
       end
     end
 
+    context 'with redis backend' do
+      let :params do
+        {
+          :backend => 'dogpile.cache.redis',
+        }
+      end
+
+      it 'configures cache backend' do
+        is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.redis')
+        is_expected.to contain_package('python-redis').with(
+          :ensure => 'installed',
+          :name   => platform_params[:python_redis_package_name],
+          :tag    => ['openstack'],
+        )
+      end
+
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-redis').with(
+            :ensure => 'latest',
+            :name   => platform_params[:python_redis_package_name],
+            :tag    => ['openstack'],
+          )
+        end
+      end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-redis')
+        end
+      end
+    end
+
+    context 'with redis sentinel backend' do
+      let :params do
+        {
+          :backend => 'dogpile.cache.redis_sentinel',
+        }
+      end
+
+      it 'configures cache backend' do
+        is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.redis_sentinel')
+        is_expected.to contain_package('python-redis').with(
+          :ensure => 'installed',
+          :name   => platform_params[:python_redis_package_name],
+          :tag    => ['openstack'],
+        )
+      end
+
+      context 'with package_ensure set' do
+        before do
+          params.merge!({
+            :package_ensure => 'latest'
+          })
+        end
+
+        it 'ensures status of the package' do
+          is_expected.to contain_package('python-redis').with(
+            :ensure => 'latest',
+            :name   => platform_params[:python_redis_package_name],
+            :tag    => ['openstack'],
+          )
+        end
+      end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-redis')
+        end
+      end
+    end
+
     context 'with etcd3gw backend' do
       let :params do
         {
@@ -317,15 +484,23 @@ describe 'oslo::cache' do
       let(:platform_params) do
         case facts[:os]['family']
         when 'Debian'
-          { :pylibmc_package_name           => 'python3-pylibmc',
+          {
+            :pylibmc_package_name           => 'python3-pylibmc',
             :python_memcache_package_name   => 'python3-memcache',
+            :python_bmemcached_package_name => 'python3-binary-memcached',
+            :python_pymemcache_package_name => 'python3-pymemcache',
+            :python_redis_package_name      => 'python3-redis',
             :python_etcd3gw_package_name    => 'python3-etcd3gw',
-            :python_pymemcache_package_name => 'python3-pymemcache' }
+          }
         when 'RedHat'
-          { :pylibmc_package_name           => 'python3-pylibmc',
+          {
+            :pylibmc_package_name           => 'python3-pylibmc',
             :python_memcache_package_name   => 'python3-memcached',
+            :python_bmemcached_package_name => 'python3-binary-memcached',
+            :python_pymemcache_package_name => 'python3-pymemcache',
+            :python_redis_package_name      => 'python3-redis',
             :python_etcd3gw_package_name    => 'python3-etcd3gw',
-            :python_pymemcache_package_name => 'python3-pymemcache' }
+          }
         end
       end
 
